@@ -12,7 +12,7 @@
 
 import yaml
 
-from django.core.urlresolvers import reverse_lazy
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
@@ -39,6 +39,8 @@ class IndexView(tables.DataTableView):
         return getattr(self, "_more", False)
 
     def get_data(self):
+        filters = self.get_filters()
+
         prev_marker = self.request.GET.get(
             NodesTable._meta.prev_pagination_param, None)
 
@@ -53,7 +55,8 @@ class IndexView(tables.DataTableView):
                 self.request,
                 marker=marker,
                 paginate=True,
-                reversed_order=reversed_order)
+                reversed_order=reversed_order,
+                filters=filters)
         except Exception:
             self._prev = self._more = False
             nodes = []
@@ -64,11 +67,15 @@ class IndexView(tables.DataTableView):
 
 class CreateView(forms.ModalFormView):
     template_name = 'cluster/nodes/create.html'
-    page_title = _("Create Node")
     form_class = nodes_forms.CreateForm
     submit_url = reverse_lazy("horizon:cluster:nodes:create")
     success_url = reverse_lazy("horizon:cluster:nodes:index")
 
+    text = _("Create Node")
+    modal_header = text
+    submit_label = text
+    page_title = text
+
 
 class DetailView(tabs.TabView):
     tab_group_class = nodes_tabs.NodeDetailTabs
@@ -110,11 +117,15 @@ class DetailView(tabs.TabView):
 
 class UpdateView(forms.ModalFormView):
     template_name = 'cluster/nodes/update.html'
-    page_title = _("Update Node")
     form_class = nodes_forms.UpdateNodeForm
     submit_url = reverse_lazy("horizon:cluster:nodes:update")
     success_url = reverse_lazy("horizon:cluster:nodes:index")
 
+    text = _("Update Node")
+    modal_header = text
+    submit_label = text
+    page_title = text
+
     @memoized.memoized_method
     def get_object(self):
         try:
