@@ -10,7 +10,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from django.core.urlresolvers import reverse_lazy
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
@@ -37,6 +37,8 @@ class IndexView(tables.DataTableView):
         return getattr(self, "_more", False)
 
     def get_data(self):
+        filters = self.get_filters()
+
         prev_marker = self.request.GET.get(
             ReceiversTable._meta.prev_pagination_param, None)
 
@@ -51,7 +53,8 @@ class IndexView(tables.DataTableView):
                 self.request,
                 marker=marker,
                 paginate=True,
-                reversed_order=reversed_order)
+                reversed_order=reversed_order,
+                filters=filters)
         except Exception:
             self._prev = self._more = False
             receivers = []
@@ -62,16 +65,21 @@ class IndexView(tables.DataTableView):
 
 class CreateView(forms.ModalFormView):
     template_name = 'cluster/receivers/create.html'
-    page_title = _("Create Receiver")
     form_class = receivers_forms.CreateReceiverForm
     submit_url = reverse_lazy("horizon:cluster:receivers:create")
     success_url = reverse_lazy("horizon:cluster:receivers:index")
 
+    text = _("Create Receiver")
+    modal_header = text
+    submit_label = text
+    page_title = text
+
 
 class DetailView(tabs.TabView):
     tab_group_class = receivers_tabs.ReceiverDetailTabs
     template_name = 'horizon/common/_detail.html'
     page_title = "{{ receiver.name }}"
+    cluster_url = 'horizon:cluster:clusters:detail'
 
     @memoized.memoized_method
     def get_object(self):
@@ -89,6 +97,8 @@ class DetailView(tabs.TabView):
         context = super(DetailView, self).get_context_data(**kwargs)
         table = ReceiversTable(self.request)
         receiver = self.get_object()
+        receiver.cluster_url = reverse_lazy(self.cluster_url,
+                                            args=[receiver.cluster_id])
         context["actions"] = table.render_row_actions(receiver)
         context["receiver"] = receiver
         context["url"] = reverse_lazy("horizon:cluster:receivers:index")
